# Hirose et al. (2024):
# Arctic Warming through Interseasonal Feedback Effect
# Suppressed by Ice Sheets in Past Interglacials

# Gnuplot script to make fig 2 using ascii data file
 
  set terminal postscript eps enhanced size 8.3,11.7 font 'Arial, 20'  # gnuplot 4.6.2
# set terminal postscript eps color    size 8.3,11.7 font 'Arial, 20'  # gnuplot 5.4.6, 6.0.0
  set output 'fig_2.eps'

  set multiplot
  set key off
  set macros

# name of input data file
  IFILE = "'dat_2.txt'"

# macros for colours
  SL = "set linetype"
  LR1 = "rgb '#ffd700'" ; LR2 = "rgb '#00bfff'" ; LR3 = "rgb '#a52a2a'"
  LR4 = "rgb '#add8e6'" ; LR5 = "rgb '#ff8c00'" ; LR6 = "rgb '#d3d3d3'"
  LR7 = "rgb '#696969'" ; LR8 = "rgb '#9acd32'" ; LR9 = "rgb '#00ff00'"  # LR9 = "rgb '#808000'"
  LRA = "rgb '#4682b4'" ; LRB = "rgb '#800080'"

# macros for different regions
# total height of figures = 0.92-0.10 = 0.82
# total height in terms of temperature = 30+5+35+5+35+5+100+5+30 = 250
  K130ALL = "set tmargin at screen 0.92-0.82*000/250 ; set yrange [-15:15] ; \
             set bmargin at screen 0.92-0.82*030/250"
  K130LND = "set tmargin at screen 0.92-0.82*035/250 ; set yrange [-15:20] ; \
             set bmargin at screen 0.92-0.82*070/250"
  K130NOI = "set tmargin at screen 0.92-0.82*075/250 ; set yrange [-15:20] ; \
             set bmargin at screen 0.92-0.82*110/250"
  K130ICE = "set tmargin at screen 0.92-0.82*115/250 ; set yrange [-55:45] ; \
             set bmargin at screen 0.92-0.82*215/250"
  K130OCN = "set tmargin at screen 0.92-0.82*220/250 ; set yrange [-15:15] ; \
             set bmargin at screen 0.92-0.82*250/250"

# macro for set-up of histogram
  SETHIST = \
  "set style data histogram ; \
   set style histogram columnstacked ; \
   set style fill solid noborder ; \
   set boxwidth 0.6 ; \
   set border 0 ; \
   set grid ytics lt 1 lc 'gray' ; \
   set xrange [-0.5:11.5] ; \
   set xtics scale 0 nomirror offset 0.0,0.25 out \
   ( 'J' 0,'F' 1,'M' 2,'A' 3,'M' 4,'J' 5,'J' 6,'A' 7,'S' 8,'O' 9,'N' 10,'D' 11) ; \
   set ytics 10 nomirror out"

# macro for set-up of line plot
  SETLINE = \
  "unset grid ; unset ytics ; unset xtics ; set xrange [2.5:14.5] ; \
   set border 15 ; set style data lines"

# label regions
  set label font ',40' center at screen 0.57,0.98 \
  'Feedback analysis: surface temperature change (^oC)'
  set label font ',40' center at screen 0.35,0.94 '130ka'
  set label font ',40' center at screen 0.79,0.94 '125ka'
  LHALF  = "set lmargin at screen 0.16 ; set rmargin at screen 0.54"
  RHALF  = "set lmargin at screen 0.60 ; set rmargin at screen 0.98"
  LABREG = "set label font ',40' rotate by 90 center at screen 0.09,0.92-0.82*"
  @LABREG(000+030)/(2*250) 'All'
  @LABREG(035+070)/(2*250) 'Land'
  @LABREG(075+110)/(2*250) 'Ice-free land'
  @LABREG(115+215)/(2*250) 'Ice-covered land'
  @LABREG(220+250)/(2*250) 'Ocean'
  set label font ',40' center at screen 0.04,0.92-0.82*000/250 '(a)'
  set label font ',40' center at screen 0.04,0.92-0.82*035/250 '(b)'
  set label font ',40' center at screen 0.04,0.92-0.82*075/250 '(c)'
  set label font ',40' center at screen 0.04,0.92-0.82*115/250 '(d)'
  set label font ',40' center at screen 0.04,0.92-0.82*220/250 '(e)'

# draw key
  KEY1="'S-B'"                      # nonlinearity of Stefan-Boltzmann law
  KEY2="'alb'"                      # surface albedo change
  KEY3="'alb{/Symbol *}clr\\\_sw'"  # nonlinear effect of surface albedo and
                                    #   clear-sky shortwave radiation changes
  KEY4="'clr\\\_sw'"                # clear-sky shortwave radiation change
  KEY5="'clr\\\_lw'"                # clear-sky longwave radiation change
  KEY6="'cld\\\_sw'"                # shortwave cloud radiative effect
  KEY7="'cld\\\_lw'"                # longwave cloud radiative effect
  KEY8="'evap'"                     # surface latent heat flux via evaporation
  KEY9="'sens'"                     # surface sensible heat flux
  KEYA="'surface'"                  # net surface energy flux including latent
                                    #   for snow/ice melting and
                                    #   heat exchange with the subsurface
  KEYB="'synergy'"                  # synergy term for local feedbacks and
                                    #   local warming sensitivity
  KEYC="'total'"                    # total of 11 components
  KEYD="'dts'"                      # surface temperature change

  SETO="set object"
  FSCR="rect from screen"
  TSCR="to screen"
  SLAB="set label font ', 25' at screen"
  set style rect front fs solid noborder
  @SETO  1 @FSCR 0.17,0.060 @TSCR 0.21,0.076 fc @LR1 ; @SLAB 0.23,0.068 @KEY1
  @SETO  2 @FSCR 0.17,0.035 @TSCR 0.21,0.051 fc @LR2 ; @SLAB 0.23,0.043 @KEY2
  @SETO  3 @FSCR 0.17,0.010 @TSCR 0.21,0.026 fc @LR3 ; @SLAB 0.23,0.018 @KEY3

  @SETO  4 @FSCR 0.39,0.060 @TSCR 0.43,0.076 fc @LR4 ; @SLAB 0.45,0.068 @KEY4
  @SETO  5 @FSCR 0.39,0.035 @TSCR 0.43,0.051 fc @LR5 ; @SLAB 0.45,0.043 @KEY5
  @SETO  6 @FSCR 0.39,0.010 @TSCR 0.43,0.026 fc @LR6 ; @SLAB 0.45,0.018 @KEY6

  @SETO  7 @FSCR 0.61,0.060 @TSCR 0.65,0.076 fc @LR7 ; @SLAB 0.67,0.068 @KEY7
  @SETO  8 @FSCR 0.61,0.035 @TSCR 0.65,0.051 fc @LR8 ; @SLAB 0.67,0.043 @KEY8
  @SETO  9 @FSCR 0.61,0.010 @TSCR 0.65,0.026 fc @LR9 ; @SLAB 0.67,0.018 @KEY9

  @SETO 10 @FSCR 0.83,0.060 @TSCR 0.87,0.076 fc @LRA ; @SLAB 0.89,0.068 @KEYA
  @SETO 11 @FSCR 0.83,0.035 @TSCR 0.87,0.051 fc @LRB ; @SLAB 0.89,0.043 @KEYB
  set arrow from screen 0.83,0.018 to screen 0.87,0.018 nohead lw 3 lc rgb 'black'
  set label font ', 25' at screen 0.89,0.018 'total'
  set style rect back fs empty border lc rgb 'black'
  @SETO 12 @FSCR 0.16,0.005 @TSCR 0.98,0.081

# subfigure 2a left (block 1 in data file ) ###########################
  @LHALF
  @SETHIST ; @K130ALL
  @SL  1 lc @LR1 ; @SL  2 lc @LR2 ; @SL  3 lc @LR3 ; @SL  4 lc @LR4
  @SL  5 lc @LR5 ; @SL  6 lc @LR6 ; @SL  7 lc @LR7 ; @SL  8 lc @LR8
  @SL  9 lc @LR9 ; @SL 10 lc @LRA ; @SL 11 lc @LRB
  plot for [i=4:15] @IFILE every ::0:0:10:0 u i
  unset label
  unset object
  unset arrow
  @SETLINE
  plot @IFILE i 0 matrix every ::3:12::12 w l lw 3 lt -1 lc rgb 'black'

# subfigure 2b left (block 2 in data file ) ###########################
  @SETHIST ; @K130LND
  @SL  2 lc @LR1 ; @SL  3 lc @LR2 ; @SL  4 lc @LR3 ; @SL  5 lc @LR4
  @SL  6 lc @LR5 ; @SL  7 lc @LR6 ; @SL  8 lc @LR7 ; @SL  9 lc @LR8
  @SL 10 lc @LR9 ; @SL 11 lc @LRA ; @SL 12 lc @LRB
  plot for [i=4:15] @IFILE every ::0:1:10:1 u i
  @SETLINE
  plot @IFILE i 1 matrix every ::3:12::12 w l lw 3 lt -1 lc rgb 'black'

# subfigure 2c left (block 3 in data file ) ###########################
  @SETHIST ; @K130NOI
  @SL  3 lc @LR1 ; @SL  4 lc @LR2 ; @SL  5 lc @LR3 ; @SL  6 lc @LR4
  @SL  7 lc @LR5 ; @SL  8 lc @LR6 ; @SL  9 lc @LR7 ; @SL 10 lc @LR8
  @SL 11 lc @LR9 ; @SL 12 lc @LRA ; @SL 13 lc @LRB
  plot for [i=4:15] @IFILE every ::0:2:10:2 u i
  @SETLINE
  plot @IFILE i 2 matrix every ::3:12::12 w l lw 3 lt -1 lc rgb 'black'

# subfigure 2d left (block 4 in data file ) ###########################
  @SETHIST ; @K130ICE
  @SL  4 lc @LR1 ; @SL  5 lc @LR2 ; @SL  6 lc @LR3 ; @SL  7 lc @LR4
  @SL  8 lc @LR5 ; @SL  9 lc @LR6 ; @SL 10 lc @LR7 ; @SL 11 lc @LR8
  @SL 12 lc @LR9 ; @SL 13 lc @LRA ; @SL 14 lc @LRB
  plot for [i=4:15] @IFILE every ::0:3:10:3 u i
  @SETLINE
  plot @IFILE i 3 matrix every ::3:12::12 w l lw 3 lt -1 lc rgb 'black'

# subfigure 2e left (block 5 in data file ) ###########################
  @SETHIST ; @K130OCN
  @SL  5 lc @LR1 ; @SL  6 lc @LR2 ; @SL  7 lc @LR3 ; @SL  8 lc @LR4
  @SL  9 lc @LR5 ; @SL 10 lc @LR6 ; @SL 11 lc @LR7 ; @SL 12 lc @LR8
  @SL 13 lc @LR9 ; @SL 14 lc @LRA ; @SL 15 lc @LRB
  plot for [i=4:15] @IFILE every ::0:4:10:4 u i
  @SETLINE
  plot @IFILE i 4 matrix every ::3:12::12 w l lw 3 lt -1 lc rgb 'black'

# subfigure 2a right (block 6 in data file ) ##########################
  @RHALF
  @SETHIST ; @K130ALL
  @SL  6 lc @LR1 ; @SL  7 lc @LR2 ; @SL  8 lc @LR3 ; @SL  9 lc @LR4
  @SL 10 lc @LR5 ; @SL 11 lc @LR6 ; @SL 12 lc @LR7 ; @SL 13 lc @LR8
  @SL 14 lc @LR9 ; @SL 15 lc @LRA ; @SL 16 lc @LRB
  plot for [i=4:15] @IFILE every ::0:5:10:5 u i
  @SETLINE
  plot @IFILE i 5 matrix every ::3:12::12 w l lw 3 lt -1 lc rgb 'black'

# subfigure 2b right (block 7 in data file ) ##########################
  @SETHIST ; @K130LND
  @SL  7 lc @LR1 ; @SL  8 lc @LR2 ; @SL  9 lc @LR3 ; @SL 10 lc @LR4
  @SL 11 lc @LR5 ; @SL 12 lc @LR6 ; @SL 13 lc @LR7 ; @SL 14 lc @LR8
  @SL 15 lc @LR9 ; @SL 16 lc @LRA ; @SL 17 lc @LRB
  plot for [i=4:15] @IFILE every ::0:6:10:6 u i
  @SETLINE
  plot @IFILE i 6 matrix every ::3:12::12 w l lw 3 lt -1 lc rgb 'black'

# subfigure 2c right (block 8 in data file ) ##########################
  @SETHIST ; @K130NOI
  @SL  8 lc @LR1 ; @SL  9 lc @LR2 ; @SL 10 lc @LR3 ; @SL 11 lc @LR4
  @SL 12 lc @LR5 ; @SL 13 lc @LR6 ; @SL 14 lc @LR7 ; @SL 15 lc @LR8
  @SL 16 lc @LR9 ; @SL 17 lc @LRA ; @SL 18 lc @LRB
  plot for [i=4:15] @IFILE every ::0:7:10:7 u i
  @SETLINE
  plot @IFILE i 7 matrix every ::3:12::12 w l lw 3 lt -1 lc rgb 'black'

# subfigure 2d right (block 9 in data file ) ##########################
  @SETHIST ; @K130ICE
  @SL  9 lc @LR1 ; @SL 10 lc @LR2 ; @SL 11 lc @LR3 ; @SL 12 lc @LR4
  @SL 13 lc @LR5 ; @SL 14 lc @LR6 ; @SL 15 lc @LR7 ; @SL 16 lc @LR8
  @SL 17 lc @LR9 ; @SL 18 lc @LRA ; @SL 19 lc @LRB
  plot for [i=4:15] @IFILE every ::0:8:10:8 u i
  @SETLINE
  plot @IFILE i 8 matrix every ::3:12::12 w l lw 3 lt -1 lc rgb 'black'

# subfigure 2e right (block 10 in data file ) #########################
  @SETHIST ; @K130OCN
  @SL 10 lc @LR1 ; @SL 11 lc @LR2 ; @SL 12 lc @LR3 ; @SL 13 lc @LR4
  @SL 14 lc @LR5 ; @SL 15 lc @LR6 ; @SL 16 lc @LR7 ; @SL 17 lc @LR8
  @SL 18 lc @LR9 ; @SL 19 lc @LRA ; @SL 20 lc @LRB
  plot for [i=4:15] @IFILE every ::0:9:10:9 u i
  @SETLINE
  plot @IFILE i 9 matrix every ::3:12::12 w l lw 3 lt -1 lc rgb 'black'

  unset multiplot

  quit
