# Hirose et al. (2024):
# Arctic Warming through Interseasonal Feedback Effect
# Suppressed by Ice Sheets in Past Interglacials

# Gnuplot script to make fig 3 using ascii data file
 
  set terminal postscript eps enhanced size 8.3,11.7 font 'Arial, 20'  # gnuplot 4.6.2
# set terminal postscript eps color    size 8.3,11.7 font 'Arial, 20'  # gnuplot 5.4.6, 6.0.0
  set output 'fig_3.eps'

  set multiplot
  set key off
  set grid lt 1 lc rgb 'grey80'
  set macros

  LIN_T1A                = "with linespoints ps 1.7 pt 5"
  LIN_T1B                = "with linespoints ps 1.5 pt 64 pi -1"
  LIN_T2A                = "with linespoints ps 1.8 pt 7"
  LIN_T2B                = "with linespoints ps 1.5 pt 65 pi -1"
  LIN_T5A                = "with linespoints ps 1.8 pt 9"
  LIN_T5B                = "with linespoints ps 1.5 pt 66 pi -1"
  PI_ES3                 = "lw 3 lt 1 lc rgb 'black'"
  PI_ES4                 = "lw 3 lt 1 lc rgb 'dark-grey'"
  T1_005k_ES3            = "lw 3 lt 1 lc rgb 'brown'"
  T1_010k_ES3            = "lw 4 lt 3 lc rgb 'brown'"
  T2_125k_ES3            = "lw 3 lt 1 lc rgb 'blue'"
  T2_130k_ES3            = "lw 4 lt 3 lc rgb 'blue'"
  T5_410k_ES3            = "lw 3 lt 1 lc rgb 'magenta'"
  T5_415k_ES3            = "lw 4 lt 3 lc rgb 'magenta'"
  T2_130k_ES4            = "lw 4 lt 3 lc rgb 'turquoise'"
  T2_130k_ES4_piIS       = "lw 3 lt 1 lc rgb 'turquoise'"
  T2_130k_ES4_piCO2      = "lw 4 lt 3 lc rgb 'web-green'"
  T2_130k_ES4_piIS_piCO2 = "lw 3 lt 1 lc rgb 'web-green'"

# plot key
  set lmargin at screen 0.54 ; set rmargin at screen 0.97
  set tmargin at screen 0.95 ; set bmargin at screen 0.70
  set border 0
  set xrange [0:11]
  set yrange [0:13]
  unset xtics
  unset ytics

  set label left at 4.5,13 font ', 25' 'ES3 PI'
  set label left at 4.5,12 font ', 25' 'ES4 PI'
  set label left at 4.5,10 font ', 25' 'ES3 5ka'
  set label left at 4.5,9  font ', 25' 'ES3 10ka'
  set label left at 4.5,8  font ', 25' 'ES3 125ka'
  set label left at 4.5,7  font ', 25' 'ES3 130ka'
  set label left at 4.5,6  font ', 25' 'ES3 410ka'
  set label left at 4.5,5  font ', 25' 'ES3 415ka'
  set label left at 4.5,3  font ', 25' 'ES4 130ka'
  set label left at 4.5,2  font ', 25' 'ES4 130ka piIS'
  set label left at 4.5,1  font ', 25' 'ES4 130ka piCO_2'
  set label left at 4.5,0  font ', 25' 'ES4 130ka piIS piCO_2'

  set pointsize 1.75
  plot '-' @LIN_T1A @PI_ES3            , \
       '-' @LIN_T1A @PI_ES4            , \
       '-' @LIN_T1A @T1_005k_ES3       , \
       '-' @LIN_T1B @T1_010k_ES3       , \
       '-' @LIN_T2A @T2_125k_ES3       , \
       '-' @LIN_T2B @T2_130k_ES3       , \
       '-' @LIN_T5A @T5_410k_ES3       , \
       '-' @LIN_T5B @T5_415k_ES3       , \
       '-' @LIN_T2B @T2_130k_ES4       , \
       '-' @LIN_T2A @T2_130k_ES4_piIS  , \
       '-' @LIN_T2B @T2_130k_ES4_piCO2 , \
       '-' @LIN_T2A @T2_130k_ES4_piIS_piCO2
   1  13
   4  13
  e
   1  12
   4  12
  e
   1  10
   4  10
  e
   1  9
   4  9
  e
   1  8
   4  8
  e
   1  7
   4  7
  e
   1  6
   4  6
  e
   1  5
   4  5
  e
   1  3
   4  3
  e
   1  2
   4  2
  e
   1  1
   4  1
  e
   1  0
   4  0
  e

  unset label
  set border 15
  set pointsize 1.5


  set xrange [1:12]
  set xtics 1 out scale 2 offset screen 0.0,0.005 \
  ('J' 1,'F' 2,'M' 3,'A'  4,'M'  5,'J'  6, \
   'J' 7,'A' 8,'S' 9,'O' 10,'N' 11,'D' 12)

# plot insolation anomaly
  set lmargin at screen 0.05 ; set rmargin at screen 0.48
  set tmargin at screen 0.95 ; set bmargin at screen 0.70
  set yrange [-10:70]
  set ytics 10 out scale 2 offset screen 0.005,0.0
  set title font ', 30' offset screen 0.0,0.005 '(a) 60^oN-90^oN TOA insolation anomaly (W/m^2)'
  plot 'dat_3.txt' u 2:($1 == 1 ?  $3 : 1/0) @LIN_T1A @PI_ES3      , \
       'dat_3.txt' u 2:($1 == 1 ?  $5 : 1/0) @LIN_T1A @T1_005k_ES3 , \
       'dat_3.txt' u 2:($1 == 1 ?  $6 : 1/0) @LIN_T1B @T1_010k_ES3 , \
       'dat_3.txt' u 2:($1 == 1 ?  $7 : 1/0) @LIN_T2A @T2_125k_ES3 , \
       'dat_3.txt' u 2:($1 == 1 ?  $8 : 1/0) @LIN_T2B @T2_130k_ES3 , \
       'dat_3.txt' u 2:($1 == 1 ?  $9 : 1/0) @LIN_T5A @T5_410k_ES3 , \
       'dat_3.txt' u 2:($1 == 1 ? $10 : 1/0) @LIN_T5B @T5_415k_ES3

# plot surface air temperature anomaly
  set tmargin at screen 0.62 ; set bmargin at screen 0.37
  set yrange [-6:6]
  set ytics 1 out scale 2 offset screen 0.005,0.0
  set title font ', 30' offset screen 0.0,0.005 '(b) 60^oN-90^oN surf. air temp. anomaly (^oC)'
  plot 'dat_3.txt' u 2:($1 == 2 ?  $3 : 1/0) @LIN_T1A @PI_ES3            , \
       'dat_3.txt' u 2:($1 == 2 ?  $5 : 1/0) @LIN_T1A @T1_005k_ES3       , \
       'dat_3.txt' u 2:($1 == 2 ?  $6 : 1/0) @LIN_T1B @T1_010k_ES3       , \
       'dat_3.txt' u 2:($1 == 2 ?  $7 : 1/0) @LIN_T2A @T2_125k_ES3       , \
       'dat_3.txt' u 2:($1 == 2 ?  $8 : 1/0) @LIN_T2B @T2_130k_ES3       , \
       'dat_3.txt' u 2:($1 == 2 ?  $9 : 1/0) @LIN_T5A @T5_410k_ES3       , \
       'dat_3.txt' u 2:($1 == 2 ? $10 : 1/0) @LIN_T5B @T5_415k_ES3
 
# plot surface air temperature anomaly for ES4 sensitivity expts
  set lmargin at screen 0.54 ; set rmargin at screen 0.97
  set title font ', 30' offset screen 0.0,0.005 '(c) 60^oN-90^oN surf. air temp. anomaly (^oC)'
  plot 'dat_3.txt' u 2:($1 == 2 ?  $4 : 1/0) @LIN_T1A @PI_ES4            , \
       'dat_3.txt' u 2:($1 == 2 ? $11 : 1/0) @LIN_T2B @T2_130k_ES4       , \
       'dat_3.txt' u 2:($1 == 2 ? $12 : 1/0) @LIN_T2A @T2_130k_ES4_piIS  , \
       'dat_3.txt' u 2:($1 == 2 ? $13 : 1/0) @LIN_T2B @T2_130k_ES4_piCO2 , \
       'dat_3.txt' u 2:($1 == 2 ? $14 : 1/0) @LIN_T2A @T2_130k_ES4_piIS_piCO2

# plot NH sea ice area
  set lmargin at screen 0.05 ; set rmargin at screen 0.48
  set tmargin at screen 0.29 ; set bmargin at screen 0.04
  set yrange [2:20]
  set ytics 2 out scale 2 offset screen 0.005,0.0
  set title font ', 30' offset screen 0.0,0.005 '(d) NH sea ice area (10^6km^2)'
  plot 'dat_3.txt' u 2:($1 == 3 ?  $3 : 1/0) @LIN_T1A @PI_ES3            , \
       'dat_3.txt' u 2:($1 == 3 ?  $5 : 1/0) @LIN_T1A @T1_005k_ES3       , \
       'dat_3.txt' u 2:($1 == 3 ?  $6 : 1/0) @LIN_T1B @T1_010k_ES3       , \
       'dat_3.txt' u 2:($1 == 3 ?  $7 : 1/0) @LIN_T2A @T2_125k_ES3       , \
       'dat_3.txt' u 2:($1 == 3 ?  $8 : 1/0) @LIN_T2B @T2_130k_ES3       , \
       'dat_3.txt' u 2:($1 == 3 ?  $9 : 1/0) @LIN_T5A @T5_410k_ES3       , \
       'dat_3.txt' u 2:($1 == 3 ? $10 : 1/0) @LIN_T5B @T5_415k_ES3

# plot NH sea ice area for ES4 sensitivity expts
  set lmargin at screen 0.54 ; set rmargin at screen 0.97
  set title font ', 30' offset screen 0.0,0.005 '(e) NH sea ice area (10^6km^2)'
  plot 'dat_3.txt' u 2:($1 == 3 ?  $4 : 1/0) @LIN_T1A @PI_ES4            , \
       'dat_3.txt' u 2:($1 == 3 ? $11 : 1/0) @LIN_T2B @T2_130k_ES4       , \
       'dat_3.txt' u 2:($1 == 3 ? $12 : 1/0) @LIN_T2A @T2_130k_ES4_piIS  , \
       'dat_3.txt' u 2:($1 == 3 ? $13 : 1/0) @LIN_T2B @T2_130k_ES4_piCO2 , \
       'dat_3.txt' u 2:($1 == 3 ? $14 : 1/0) @LIN_T2A @T2_130k_ES4_piIS_piCO2

  unset multiplot

  quit
