# Hirose et al. (2024):
# Arctic Warming through Interseasonal Feedback Effect
# Suppressed by Ice Sheets in Past Interglacials

# Gnuplot script to make fig 4 using ascii data file
 
  set terminal postscript eps enhanced size 8.3,8.3 font 'Arial, 30'  # gnuplot 4.6.2
# set terminal postscript eps color    size 8.3,8.3 font 'Arial, 30'  # gnuplot 5.4.6, 6.0.0
  set output 'fig_4.eps'

  set multiplot
  set key off
  set macros

  PI_ES3                 = "w p lw 8 ps 4.5 pt  5 lc rgb 'black'"
  T1_005k_ES3            = "w p lw 8 ps 4.5 pt  5 lc rgb 'brown'"
  T1_010k_ES3            = "w p lw 8 ps 4.0 pt 64 lc rgb 'brown'"
  T2_125k_ES3            = "w p lw 8 ps 5.0 pt  7 lc rgb 'blue'"
  T2_130k_ES3            = "w p lw 8 ps 4.5 pt 65 lc rgb 'blue'"
  T5_410k_ES3            = "w p lw 8 ps 5.2 pt  9 lc rgb 'magenta'"
  T5_415k_ES3            = "w p lw 8 ps 4.5 pt 66 lc rgb 'magenta'"
  T2_130k_ES4            = "w p lw 8 ps 4.5 pt 65 lc rgb 'turquoise'"
  T2_130k_ES4_piIS       = "w p lw 8 ps 5.0 pt  7 lc rgb 'turquoise'"
  T2_130k_ES4_piCO2      = "w p lw 8 ps 4.5 pt 65 lc rgb 'web-green'"
  T2_130k_ES4_piIS_piCO2 = "w p lw 8 ps 5.0 pt  7 lc rgb 'web-green'"

  set tmargin at screen 0.95 ; set bmargin at screen 0.10
  set lmargin at screen 0.10 ; set rmargin at screen 0.95

  set xrange [-4:3]
  set xtics 1 out scale 2
  set format x '%1.0f'
  set xlabel font ', 40' '60^oN-90^oN annual surface air temperature anomaly ( ^oC )'
  set yrange [-5:2]
  set ytics 1 out scale 2 offset screen 0.005,0.0
  set format y '%1.0f'
  set ylabel offset screen 0.015,0.0 font ', 40' 'Aug-Sep NH sea ice area anomaly (10^6km^2)'
  set grid

# draw rectangle around key
  set object rect from  1.70,-0.95 to  2.90, 1.90 lw 2
  set object rect from -3.90,-4.90 to -1.10,-3.10 lw 2

# label the key for AMOC type
  set label center at first  2.00,01.70 'ES3'
  set label left   at first  2.20,01.35 'PI'
  set label left   at first  2.20,01.00 '5ka'
  set label left   at first  2.20,00.65 '10ka'
  set label left   at first  2.20,00.30 '125ka'
  set label left   at first  2.20,-0.05 '130ka'
  set label left   at first  2.20,-0.40 '410ka'
  set label left   at first  2.20,-0.75 '415ka'
  set label center at first -3.60,-3.30 'ES4'
  set label center at first -2.95,-3.30 'ORB'
  set label center at first -2.20,-3.30 'IS'
  set label center at first -1.45,-3.30 'CO_2'
  set label center at first -2.95,-3.65 'PI'
  set label center at first -2.20,-3.65 'PI'
  set label center at first -1.45,-3.65 'PI'
  set label center at first -2.95,-4.00 '130ka'
  set label center at first -2.20,-4.00 '130ka'
  set label center at first -1.45,-4.00 '130ka'
  set label center at first -2.95,-4.35 '130ka'
  set label center at first -2.20,-4.35 'PI'
  set label center at first -1.45,-4.35 '130ka'
  set label center at first -2.95,-4.70 '130ka'
  set label center at first -2.20,-4.70 '130ka'
  set label center at first -1.45,-4.70 'PI'

  plot '-' @PI_ES3                 , \
       '-' @PI_ES3                 , \
       '-' @T1_005k_ES3            , \
       '-' @T1_010k_ES3            , \
       '-' @T2_125k_ES3            , \
       '-' @T2_130k_ES3            , \
       '-' @T5_410k_ES3            , \
       '-' @T5_415k_ES3            , \
       '-' @PI_ES3                 , \
       '-' @T2_130k_ES4            , \
       '-' @T2_130k_ES4_piIS       , \
       '-' @T2_130k_ES4_piCO2
   0.00  0.00
  e
   2.00  1.35
  e
   2.00  1.00
  e
   2.00  0.65
  e
   2.00  0.30
  e 
   2.00 -0.05
  e 
   2.00 -0.40
  e 
   2.00 -0.75
  e 
  -3.60 -3.65
  e 
  -3.60 -4.00
  e 
  -3.60 -4.35
  e 
  -3.60 -4.70
  e 

  unset xtics
  unset ytics
  unset xlabel
  unset ylabel
  unset label
  unset object
  set border 0

  plot 'dat_4_s2.txt' u 7:($1 == 1 ? $8 : 1/0) @T1_005k_ES3 , \
       'dat_4_s2.txt' u 7:($1 == 2 ? $8 : 1/0) @T1_010k_ES3 , \
       'dat_4_s2.txt' u 7:($1 == 3 ? $8 : 1/0) @T2_125k_ES3 , \
       'dat_4_s2.txt' u 7:($1 == 4 ? $8 : 1/0) @T2_130k_ES3 , \
       'dat_4_s2.txt' u 7:($1 == 5 ? $8 : 1/0) @T5_410k_ES3 , \
       'dat_4_s2.txt' u 7:($1 == 6 ? $8 : 1/0) @T5_415k_ES3 , \
       'dat_4_s2.txt' u 7:($1 == 7 ? $8 : 1/0) @T2_130k_ES4 , \
       'dat_4_s2.txt' u 7:($1 == 8 ? $8 : 1/0) @T2_130k_ES4_piIS , \
       'dat_4_s2.txt' u 7:($1 == 9 ? $8 : 1/0) @T2_130k_ES4_piCO2

  unset multiplot

  quit
