# Hirose et al. (2024):
# Arctic Warming through Interseasonal Feedback Effect
# Suppressed by Ice Sheets in Past Interglacials

# Gnuplot script to make fig S2 using ascii data file
 
  set terminal postscript eps enhanced size 8.3,8.3 font 'Arial, 30'  # gnuplot 4.6 patchlevel 2
# set terminal postscript eps color    size 8.3,8.3 font 'Arial, 30'  # gnuplot 5.4 patchlevel 6
  set output 'fig_s2.eps'

  set multiplot
  set key off
  set macros

  PI_ES3                 = "w p lw 8 ps 4.5 pt  5 lc rgb 'black'"
  T1_005k_ES3            = "w p lw 8 ps 4.5 pt  5 lc rgb 'brown'"
  T1_010k_ES3            = "w p lw 8 ps 4.0 pt 64 lc rgb 'brown'"
  T2_125k_ES3            = "w p lw 8 ps 5.0 pt  7 lc rgb 'blue'"
  T2_130k_ES3            = "w p lw 8 ps 4.5 pt 65 lc rgb 'blue'"
  T5_410k_ES3            = "w p lw 8 ps 5.2 pt  9 lc rgb 'magenta'"
  T5_415k_ES3            = "w p lw 8 ps 4.5 pt 66 lc rgb 'magenta'"
  T2_130k_ES4            = "w p lw 8 ps 4.5 pt 65 lc rgb 'turquoise'"
  T2_130k_ES4_piIS       = "w p lw 8 ps 5.0 pt  7 lc rgb 'turquoise'"
  T2_130k_ES4_piCO2      = "w p lw 8 ps 4.5 pt 65 lc rgb 'web-green'"
  T2_130k_ES4_piIS_piCO2 = "w p lw 8 ps 5.0 pt  7 lc rgb 'web-green'"

  set tmargin at screen 0.95 ; set bmargin at screen 0.10
  set lmargin at screen 0.10 ; set rmargin at screen 0.95

  set xrange [-4:3]
  set xtics 1 out scale 2
  set format x '%1.0f'
  set xlabel font ', 40' 'Global annual surface air temperature anomaly ( ^oC )'
  set yrange [-4:3]
  set ytics 1 out scale 2 offset screen 0.005,0.0
  set format y '%1.0f'
  set ylabel offset screen 0.015,0.0 font ', 40' '60^oN-90^oN annual surface air temperature anomaly ( ^oC )'
  set grid

# draw diagonal line along y=x
  set arrow from -4,-4 to 3,3 nohead lc rgb 'black' lt 2

# draw rectangle around key
  set object rect from -3.90,00.05 to -2.70, 2.90 lw 2
  set object rect from  0.10,-3.90 to  2.90,-2.10 lw 2

# label the key for AMOC type
  set label center at first -3.60,02.70 'ES3'
  set label left   at first -3.40,02.35 'PI'
  set label left   at first -3.40,02.00 '5ka'
  set label left   at first -3.40,01.65 '10ka'
  set label left   at first -3.40,01.30 '125ka'
  set label left   at first -3.40,00.95 '130ka'
  set label left   at first -3.40,00.60 '410ka'
  set label left   at first -3.40,00.25 '415ka'
  set label center at first  0.40,-2.30 'ES4'
  set label center at first  1.05,-2.30 'ORB'
  set label center at first  1.80,-2.30 'IS'
  set label center at first  2.55,-2.30 'CO_2'
  set label center at first  1.05,-2.65 'PI'
  set label center at first  1.80,-2.65 'PI'
  set label center at first  2.55,-2.65 'PI'
  set label center at first  1.05,-3.00 '130ka'
  set label center at first  1.80,-3.00 '130ka'
  set label center at first  2.55,-3.00 '130ka'
  set label center at first  1.05,-3.35 '130ka'
  set label center at first  1.80,-3.35 'PI'
  set label center at first  2.55,-3.35 '130ka'
  set label center at first  1.05,-3.70 '130ka'
  set label center at first  1.80,-3.70 '130ka'
  set label center at first  2.55,-3.70 'PI'

  plot '-' @PI_ES3            , \
       '-' @PI_ES3            , \
       '-' @T1_005k_ES3       , \
       '-' @T1_010k_ES3       , \
       '-' @T2_125k_ES3       , \
       '-' @T2_130k_ES3       , \
       '-' @T5_410k_ES3       , \
       '-' @T5_415k_ES3       , \
       '-' @PI_ES3            , \
       '-' @T2_130k_ES4       , \
       '-' @T2_130k_ES4_piIS  , \
       '-' @T2_130k_ES4_piCO2
   0.00  0.00
  e
  -3.60  2.35
  e
  -3.60  2.00
  e
  -3.60  1.65
  e
  -3.60  1.30
  e
  -3.60  0.95
  e
  -3.60  0.60
  e
  -3.60  0.25
  e
   0.40 -2.65
  e
   0.40 -3.00
  e
   0.40 -3.35
  e
   0.40 -3.70
  e

  unset xtics
  unset ytics
  unset xlabel
  unset ylabel
  unset label
  unset object
  set border 0

  plot 'dat_4_s2.txt' u 9:($1 == 1 ? $7 : 1/0) @T1_005k_ES3 , \
       'dat_4_s2.txt' u 9:($1 == 2 ? $7 : 1/0) @T1_010k_ES3 , \
       'dat_4_s2.txt' u 9:($1 == 3 ? $7 : 1/0) @T2_125k_ES3 , \
       'dat_4_s2.txt' u 9:($1 == 4 ? $7 : 1/0) @T2_130k_ES3 , \
       'dat_4_s2.txt' u 9:($1 == 5 ? $7 : 1/0) @T5_410k_ES3 , \
       'dat_4_s2.txt' u 9:($1 == 6 ? $7 : 1/0) @T5_415k_ES3 , \
       'dat_4_s2.txt' u 9:($1 == 7 ? $7 : 1/0) @T2_130k_ES4 , \
       'dat_4_s2.txt' u 9:($1 == 8 ? $7 : 1/0) @T2_130k_ES4_piIS , \
       'dat_4_s2.txt' u 9:($1 == 9 ? $7 : 1/0) @T2_130k_ES4_piCO2

  unset multiplot

  quit
