# Hirose et al. (2024):
# Arctic Warming through Interseasonal Feedback Effect
# Suppressed by Ice Sheets in Past Interglacials

# Gnuplot script to make fig S3 using ascii data file
 
  set terminal postscript eps enhanced size 11.7,8.3 font 'Arial, 25'  # gnuplot 4.6.2
# set terminal postscript eps color    size 11.7,8.3 font 'Arial, 25'  # gnuplot 5.4.6, 6.0.0
  set output 'fig_s8.eps'

  set multiplot
  set key off
  set grid lt 1 lc rgb 'grey80'
  set macros

  LTYPE1      = "with linespoints pt 7"
  LTYPE2      = "with linespoints pt 65 pi -1"
  LTYPE1K     = "with linespoints pt 7  pi -1"
  LTYPE2K     = "with linespoints pt 65 pi -1"
  T1_005k_ES3 = "lw 3 lt 1 lc rgb 'brown'"
  T1_010k_ES3 = "lw 2 lt 3 lc rgb 'brown'"
  T2_125k_ES3 = "lw 3 lt 1 lc rgb 'blue'"
  T2_130k_ES3 = "lw 2 lt 3 lc rgb 'blue'"
  T5_410k_ES3 = "lw 3 lt 1 lc rgb 'magenta'"
  T5_415k_ES3 = "lw 2 lt 3 lc rgb 'magenta'"

# plot key
  set tmargin at screen 0.925 ; set bmargin at screen 0.525
  set lmargin at screen 0.675 ; set rmargin at screen 0.925
  set border 0
  set xrange [0:11]
  set yrange [0:7]
  unset xtics
  unset ytics

  set label center at 6.0,7.5 font ', 40' '70^oN-90^oN'
  set label center at 6.0,6.5 font ', 40' 'cloud cover'
  set label left   at 6.5,5.0 font ', 35' '5ka'
  set label left   at 6.5,4.0 font ', 35' '10ka'
  set label left   at 6.5,3.0 font ', 35' '125ka'
  set label left   at 6.5,2.0 font ', 35' '130ka'
  set label left   at 6.5,1.0 font ', 35' '410ka'
  set label left   at 6.5,0.0 font ', 35' '415ka'

  set pointsize 1.75
  plot '-' @LTYPE1K @T1_005k_ES3       , \
       '-' @LTYPE2K @T1_010k_ES3       , \
       '-' @LTYPE1K @T2_125k_ES3       , \
       '-' @LTYPE2K @T2_130k_ES3       , \
       '-' @LTYPE1K @T5_410k_ES3       , \
       '-' @LTYPE2K @T5_415k_ES3
   2.5  5
   5.5  5
  e
   2.5  4
   5.5  4
  e
   2.5  3
   5.5  3
  e
   2.5  2
   5.5  2
  e
   2.5  1
   5.5  1
  e
   2.5  0
   5.5  0
  e

  unset label
  set border 15
  set pointsize 1.5

  set xtics 1 out scale 2 offset screen 0.0,0.005 \
  ('J' 1,'F' 2,'M' 3,'A'  4,'M'  5,'J'  6, \
   'J' 7,'A' 8,'S' 9,'O' 10,'N' 11,'D' 12)

# plot total clouds
  set tmargin at screen 0.925 ; set bmargin at screen 0.525
  set lmargin at screen 0.300 ; set rmargin at screen 0.700
  set xrange [1:12]
  set yrange [0.6:0.95]
  set ytics 0.05 out scale 2 offset screen 0.005,0.0
  set format y '%1.2f'
  set title font ', 35' offset screen 0.0,0.005 '(a) Total cloud cover'

  plot 'dat_s8.txt' u 2:($1 ==  1 ? $3 : 1/0) @LTYPE1 @T1_005k_ES3 , \
       'dat_s8.txt' u 2:($1 ==  1 ? $4 : 1/0) @LTYPE2 @T1_010k_ES3 , \
       'dat_s8.txt' u 2:($1 ==  1 ? $5 : 1/0) @LTYPE1 @T2_125k_ES3 , \
       'dat_s8.txt' u 2:($1 ==  1 ? $6 : 1/0) @LTYPE2 @T2_130k_ES3 , \
       'dat_s8.txt' u 2:($1 ==  1 ? $7 : 1/0) @LTYPE1 @T5_410k_ES3 , \
       'dat_s8.txt' u 2:($1 ==  1 ? $8 : 1/0) @LTYPE2 @T5_415k_ES3

# plot low level cloud cover
  unset label
  set tmargin at screen 0.400 ; set bmargin at screen 0.050
  set lmargin at screen 0.075 ; set rmargin at screen 0.325
  set yrange [0.0:0.6]
  set ytics 0.1 out scale 2 offset screen 0.005,0.0
  set format y '%1.1f'
  set title font ', 35' offset screen 0.0,0.005 '(b) Low level cloud cover'

  plot 'dat_s8.txt' u 2:($1 ==  2 ? $3 : 1/0) @LTYPE1 @T1_005k_ES3 , \
       'dat_s8.txt' u 2:($1 ==  2 ? $4 : 1/0) @LTYPE2 @T1_010k_ES3 , \
       'dat_s8.txt' u 2:($1 ==  2 ? $5 : 1/0) @LTYPE1 @T2_125k_ES3 , \
       'dat_s8.txt' u 2:($1 ==  2 ? $6 : 1/0) @LTYPE2 @T2_130k_ES3 , \
       'dat_s8.txt' u 2:($1 ==  2 ? $7 : 1/0) @LTYPE1 @T5_410k_ES3 , \
       'dat_s8.txt' u 2:($1 ==  2 ? $8 : 1/0) @LTYPE2 @T5_415k_ES3

# plot mid-level cloud cover
  set lmargin at screen 0.375 ; set rmargin at screen 0.625
  set title font ', 35' offset screen 0.0,0.005 '(c) Mid-level cloud cover'

  plot 'dat_s8.txt' u 2:($1 ==  3 ? $3 : 1/0) @LTYPE1 @T1_005k_ES3 , \
       'dat_s8.txt' u 2:($1 ==  3 ? $4 : 1/0) @LTYPE2 @T1_010k_ES3 , \
       'dat_s8.txt' u 2:($1 ==  3 ? $5 : 1/0) @LTYPE1 @T2_125k_ES3 , \
       'dat_s8.txt' u 2:($1 ==  3 ? $6 : 1/0) @LTYPE2 @T2_130k_ES3 , \
       'dat_s8.txt' u 2:($1 ==  3 ? $7 : 1/0) @LTYPE1 @T5_410k_ES3 , \
       'dat_s8.txt' u 2:($1 ==  3 ? $8 : 1/0) @LTYPE2 @T5_415k_ES3

# plot low level cloud cover
  set lmargin at screen 0.675 ; set rmargin at screen 0.925
  set title font ', 35' offset screen 0.0,0.005 '(d) High level cloud cover'

  plot 'dat_s8.txt' u 2:($1 ==  4 ? $3 : 1/0) @LTYPE1 @T1_005k_ES3 , \
       'dat_s8.txt' u 2:($1 ==  4 ? $4 : 1/0) @LTYPE2 @T1_010k_ES3 , \
       'dat_s8.txt' u 2:($1 ==  4 ? $5 : 1/0) @LTYPE1 @T2_125k_ES3 , \
       'dat_s8.txt' u 2:($1 ==  4 ? $6 : 1/0) @LTYPE2 @T2_130k_ES3 , \
       'dat_s8.txt' u 2:($1 ==  4 ? $7 : 1/0) @LTYPE1 @T5_410k_ES3 , \
       'dat_s8.txt' u 2:($1 ==  4 ? $8 : 1/0) @LTYPE2 @T5_415k_ES3

  unset multiplot

  quit
